@@ -63,7 +63,7 @@ void SQLThread::run(void)
         SQLCHAR stat[10];
         SQLCHAR errmsg[128];
         SQLSMALLINT mlen, col, cols;
-#if ODBCVER >= 0x0300
+#if ODBCVER >= 0x0300 && !defined(__ppc__)
 	SQLINTEGER rowcnt;
 #else
         long int rowcnt;
@@ -123,7 +123,7 @@ void SQLThread::run(void)
 	Thread::yield();
 
         SQLRowCount(hstmt, &rowcnt);
-        snprintf(buf, sizeof(buf), "%d", rowcnt);
+        snprintf(buf, sizeof(buf), "%d", (int)rowcnt);
 	lock();
 	interp->setNumber("sql.rows", buf);
 	release();
