@@ -598,7 +598,9 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 	bool defs = false;
 	bool ripple = cmds->ripple;
 	bool wrapper = false;
+	bool keydata = false;
 	merge_t *merge;
+	char *tok;
 
 	if(strstr(".bat.cmd", cp))
 		mscmd = true;
@@ -678,6 +680,7 @@ compile:
 	loopid = looplevel = 0;
 	bool then = false;
 	events = NULL;
+	keydata = false;
 
 	setString(csname, sizeof(csname), name);
 	cp = strstr(csname, "::");
@@ -800,6 +803,108 @@ compile:
 				}
 			}
 
+			bp = buffer;
+			while(isspace(*bp))
+				++bp;
+
+			if(!*bp && keydata)
+				continue;
+
+			if(*bp == '#' && keydata)
+				continue;
+
+			if(!strnicmp(bp, "%%", 2) && keydata)
+				continue;
+
+			if(isalpha(*bp) && ripple && !script->first)
+			{
+				while(isalnum(*bp))
+					++bp;
+
+				while(isspace(*bp))
+					++bp;
+
+				if(*bp == '=')
+				{
+					snprintf(namebuf, sizeof(namebuf), "%s.%s",
+						script->name, strtok_r(buffer, " \t\r\n=", &tok));
+					cp = ++bp;
+						
+					while(isspace(*cp))
+						++cp;
+
+					bp = bp + strlen(bp) - 1;
+					while(bp > cp && isspace(*bp))
+						*(bp--) = 0;
+
+					if(*cp == '\"' && cp[strlen(cp) - 1] == '\"')
+					{
+						cp[strlen(cp) - 1] = 0;
+						++cp;
+					}
+                    else if(*cp == '\'' && cp[strlen(cp) - 1] == '\'')
+                    {
+                        cp[strlen(cp) - 1] = 0;
+                        ++cp;
+                    }
+                    else if(*cp == '{' && cp[strlen(cp) - 1] == '}')
+                    {
+                        cp[strlen(cp) - 1] = 0;
+                        ++cp;
+                    }
+
+					setValue(namebuf, cp);
+					keydata = true;
+					continue;
+				}
+			}
+
+			if(keydata && !script->first)
+			{
+				command = "_keydata_";
+				handler = cmds->getHandler("_keydata_");
+				keydata = false;
+			}
+			else
+				handler = NULL;
+
+			if(handler)
+			{
+				line = (Line *)alloc(sizeof(Line));
+				line->cmd = command;
+				line->line = number++;
+				line->lnum = lnum;
+				line->cmask = cmask;
+				line->mask = script->mask;
+				line->next = NULL;
+				line->args = (const char **)alloc(sizeof(char *));
+				line->argc = 0;
+				line->args[0] = NULL;
+
+				err = cmds->check(command, line, this);
+				if(err)
+				{
+					if(*err)
+						slog.error("%s(%d): %s: %s", filename, lnum, command, err);
+				}
+				else
+				{
+					++count;
+					if(!script->first)
+						script->first = line;
+					else
+						last->next = line;
+					last = line;
+				}
+			}
+		
+			bp = buffer;
+			while(isspace(*bp) && keydata)
+				++bp;
+
+			if(!*bp && keydata)
+				continue;
+
 			bp = buffer;
 			if(embed)
 			{
