@@ -726,7 +726,6 @@ bool ScriptMethods::scrDecimal(void)
 bool ScriptMethods::scrError(void)
 {
 	char buffer[256];
-	unsigned len = 0;
 	const char *cp;
 	buffer[0] = 0;
 
@@ -770,7 +769,6 @@ bool ScriptMethods::scrSignal(void)
 
 bool ScriptMethods::scrThrow(void)
 {
-	Line *line = getLine();
 	const char *cp = getOption(NULL);
 
 	if(!cp)
@@ -876,13 +874,13 @@ set:
 
 bool ScriptMethods::scrCounter(void)
 {
-	unsigned ival = 0;
+	unsigned long lval = 0;
 	const char *err = NULL;
 	const char *cp = getMember();
 	Symbol *sym;
 
 	if(cp)
-		ival = atoi(cp) - 1;
+		lval = atol(cp) - 1;
 
 	while(NULL != (cp = getOption(NULL)))
 	{
@@ -897,7 +895,7 @@ bool ScriptMethods::scrCounter(void)
 			err = "var-already-defined";
 			continue;
 		}
-		snprintf(sym->data, sym->size + 1, "%ld", ival);
+		snprintf(sym->data, sym->size + 1, "%ld", lval);
 		sym->type = symCOUNTER;
 	}
 	if(err)
@@ -1465,7 +1463,6 @@ bool ScriptMethods::scrExpr(void)
 bool ScriptMethods::scrIndex(void)
 {
 	Symbol *sym;
-	const char *mem = getMember();
 	const char *opt;
 	long iNumber;
 
@@ -1764,10 +1761,8 @@ retry:
 bool ScriptMethods::scrCall(void)
 {
         Line *line = getLine();
-	unsigned prior = stack;
 	const char *cmd = line->cmd;
 	const char *cp, *vp;
-	bool trans = false;
 	unsigned idx = 0;
 	Symbol *sym;
 	
@@ -1989,7 +1984,7 @@ bool ScriptMethods::scrFor(void)
 	sym = getKeysymbol("index");
 	if(sym)
 	{
-		snprintf(buffer, sizeof(buffer), "%ld", index);
+		snprintf(buffer, sizeof(buffer), "%d", index);
 		commit(sym, buffer);
 	}
 
@@ -2074,7 +2069,7 @@ bool ScriptMethods::scrForeach(void)
 	sym = getKeysymbol("index");
 	if(sym)
 	{
-		snprintf(buffer, 11, "%ld", index);
+		snprintf(buffer, 11, "%d", index);
 		commit(sym, buffer);
 	}		
 
@@ -2102,6 +2097,7 @@ bool ScriptMethods::scrForeach(void)
 		if(a->head == a->tail)
 			goto failed;
 		opt = extract(src);
+	default:
 		break;
 	case symPROPERTY:
                 memcpy(&p, &sym->data, sizeof(p));
